# nde-policykit

## Overview

nde-policykit is the polkit authentification agent of Nde.

[polkit](https://www.freedesktop.org/wiki/Software/polkit/) is a software framework
to handle privileges of processes.
In Nde it is e. g. used to extend the privileges of the GUI tools of
[nde-admin](https://github.com/lxqt/lxqt-admin/). These are launched by a regular
user. But in order to apply the settings they deal with root privileges are needed
and acquired via polkit.
Among the various components of polkit the authentication agent is the one to
query the user for credentials by dialogue windows like this one of nde-policykit.
![nde-policykit: GUI](nde-policykit_gui.png)
While there's only a single implementation of all other polkit components various
different authentication agents are provided by the various desktop environments.
Basically these can be used interchangeably, that is nde-policykit can be used
in an LXDE session or lxpolkit, the authentication agent of LXDE, can be used in
an Xfce session. Most of the time it's better to use the implementation provided
by a distinct desktop environment as it integrates better, though.

Technically, nde-policykit is just a single binary `nde-policykit-agent` which
is running as [Nde Module](https://github.com/lxqt/lxqt-session#nde-modules)
and launching the GUI on demand.

Note that the naming nde-policykit is strictly speaking an anachronism. It refers
to Policykit which was the predecessor of polkit. The name wasn't changed when
Policykit was replaced by polkit as both provide roughly the same features albeit
they are technically different.

## Installing

### Compiling sources

Runtime dependencies are polkit-qt5 and [libnde](https://github.com/nde/libnde).
Additional build dependencies are CMake and optionally Git to pull latest VCS
checkouts. The localization files were outsourced to repository
[nde-l10n](https://github.com/lxqt/lxqt-l10n) so the corresponding dependencies
are needed, too. Please refer to this repository's `README.md` for further information.

Code configuration is handled by CMake. CMake variable `CMAKE_INSTALL_PREFIX`
has to be set to `/usr` on most operating systems.

To build run `make`, to install `make install` which accepts variable `DESTDIR`
as usual.

### Binary packages

#### Arch Linux

The latest release is provided by package `nde-policykit` in repository community,
the actual master checkout can be compiled by packages `nde-policykit-git` from
the [AUR](https://aur.archlinux.org).

#### Debian

Package `nde-policykit` is available in the official repositories as of Debian
stretch. For now it is comprising the translations as well but these will probably
be outsourced in package `nde-policykit-l10n` one day.

#### Fedora

Package `nde-policykit` is available as of Fedora 22.

#### openSUSE

Package `nde-policykit` is providing the binary, `nde-policykit-lang` the
translations. Both are available as of openSUSE Leap 42.1.

## Configuration, Usage

Like all Nde Modules `nde-policykit-agent` can be adjusted from section
"Basic Settings" in configuration dialogue
[Nde Session Settings](https://github.com/lxqt/lxqt-session#nde-session-settings)
of [nde-session](https://github.com/lxqt/lxqt-session).

From a user's point of view the usage is limited to interacting with the GUI as
seen above.


### Translation (Weblate)

<a href="https://weblate.lxqt.org/projects/lxqt/lxqt-policykit-agent/">
<img src="https://weblate.lxqt.org/widgets/nde/-/nde-policykit-agent/multi-auto.svg" alt="Translation status" />
</a>
